pub struct Application { /* private fields */ }Expand description
Built rivet runtime that implements the dispatch contract.
Implementations
Sourceimpl Application
impl Application
Sourcepub fn route_count(&self) -> usize
pub fn route_count(&self) -> usize
Number of routes registered in the runtime.
Sourcepub fn middleware_count(&self) -> usize
pub fn middleware_count(&self) -> usize
Number of middleware instances in the runtime chain.
Sourcepub fn make<T: Any + Send + Sync + 'static>(&self) -> Result<Arc<T>, RivetError>
pub fn make<T: Any + Send + Sync + 'static>(&self) -> Result<Arc<T>, RivetError>
Resolve a typed service instance from the application container.
Sourcepub fn config(&self, key: &str) -> Option<ConfigValue>
pub fn config(&self, key: &str) -> Option<ConfigValue>
Read a configuration value by dot-notation key.
Sourcepub fn config_typed<T: FromConfigValue>(&self, key: &str) -> Option<T>
pub fn config_typed<T: FromConfigValue>(&self, key: &str) -> Option<T>
Read and convert a configuration value by dot-notation key.
Sourcepub fn init_logging(&self)
pub fn init_logging(&self)
Initialize rivet logging runtime and configured handlers.
Sourcepub fn log_serving(&self, addr: SocketAddr)
pub fn log_serving(&self, addr: SocketAddr)
Log that the application is starting to serve requests.