Builder

Struct Builder 

pub struct Builder { /* private fields */ }
Builds an Application from rivet modules and foundation backends.

Build order is deterministic:

  1. configure modules
  2. collect/register/boot providers
  3. collect routes
  4. collect middleware

Implementations

Source

impl Builder

pub fn with_defaults() -> Self

Create a new builder using default in-memory foundation backends.

pub fn new(container: Arc<dyn Container>, config: Box<dyn Config>) -> Self

Create a new builder with a foundation container and config backend.

pub fn with_module(self, module: Box<dyn RivetModule>) -> Self

Register a module in build order.

pub fn with_provider(self, provider: ProviderFactory) -> Self

Register one compile-time provider constructor.

pub fn with_providers(self, providers: &[ProviderFactory]) -> Self

Register a static provider constructor list.

pub fn module_count(&self) -> usize

Number of modules currently queued for build.

pub fn build(self) -> Result<Application, RivetError>

Build a runtime Application by executing all build stages.