Application

Struct Application 

pub struct Application { /* private fields */ }
Built rivet runtime that implements the dispatch contract.

Implementations

Source

impl Application

pub fn route_count(&self) -> usize

Number of routes registered in the runtime.

pub fn middleware_count(&self) -> usize

Number of middleware instances in the runtime chain.

pub fn make<T: Any + Send + Sync + 'static>(&self) -> Result<Arc<T>, RivetError>

Resolve a typed service instance from the application container.

pub fn config(&self, key: &str) -> Option<ConfigValue>

Read a configuration value by dot-notation key.

pub fn config_typed<T: FromConfigValue>(&self, key: &str) -> Option<T>

Read and convert a configuration value by dot-notation key.

pub fn init_logging(&self)

Initialize rivet logging runtime and configured handlers.

pub fn log_serving(&self, addr: SocketAddr)

Log that the application is starting to serve requests.